var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
};
import React, { useState } from 'react';
import { MenuLinkItem } from '@teambit/design.ui.surfaces.menu.link-item';
import { Dropdown } from '@teambit/evangelist.surfaces.dropdown';
import { Tab } from '@teambit/ui-foundation.ui.use-box.tab';
import { UserAvatar } from '@teambit/design.ui.avatar';
import { LineSkeleton } from '@teambit/base-ui.loaders.skeleton';
import classNames from 'classnames';
import styles from './version-dropdown.module.scss';
import { VersionInfo } from './version-info';
import { LaneInfo } from './lane-info';
import { SimpleVersion } from './version-dropdown-placeholder';
export const LOCAL_VERSION = 'workspace';
export const VersionDropdown = React.memo(_VersionDropdown);
const VersionMenu = React.memo(_VersionMenu);
function _VersionDropdown(_a) {
    var { currentVersion, latestVersion, localVersion, useCurrentVersionLog, hasMoreVersions, loading, overrideVersionHref, className, placeholderClassName, getActiveTabIndex, dropdownClassName, menuClassName, showVersionDetails = true, disabled, PlaceholderComponent: _PlaceholderComponent, currentLane, useComponentVersions, lanes } = _a, rest = __rest(_a, ["currentVersion", "latestVersion", "localVersion", "useCurrentVersionLog", "hasMoreVersions", "loading", "overrideVersionHref", "className", "placeholderClassName", "getActiveTabIndex", "dropdownClassName", "menuClassName", "showVersionDetails", "disabled", "PlaceholderComponent", "currentLane", "useComponentVersions", "lanes"]);
    const [key, setKey] = useState(0);
    const singleVersion = !hasMoreVersions;
    const [open, setOpen] = useState(false);
    React.useEffect(() => {
        if (loading && open) {
            setOpen(false);
        }
    }, [loading]);
    const handlePlaceholderClicked = (e) => {
        if (loading)
            return;
        if (e.target === e.currentTarget) {
            setOpen((o) => !o);
        }
    };
    const defaultPlaceholder = (React.createElement(SimpleVersion, { useCurrentVersionLog: useCurrentVersionLog, disabled: disabled, className: placeholderClassName, currentVersion: currentVersion, onClick: handlePlaceholderClicked, hasMoreVersions: hasMoreVersions, loading: loading, showFullVersion: currentVersion === 'workspace' }));
    const PlaceholderComponent = _PlaceholderComponent ? (React.createElement(_PlaceholderComponent, { useCurrentVersionLog: useCurrentVersionLog, disabled: disabled, className: placeholderClassName, currentVersion: currentVersion, onClick: handlePlaceholderClicked, hasMoreVersions: hasMoreVersions, loading: loading, showFullVersion: currentVersion === 'workspace' })) : (defaultPlaceholder);
    if (disabled || (singleVersion && !loading)) {
        return React.createElement("div", { className: classNames(styles.noVersions, className) }, PlaceholderComponent);
    }
    return (React.createElement("div", Object.assign({}, rest, { className: classNames(styles.versionDropdown, className) }),
        React.createElement(Dropdown, { className: classNames(styles.dropdown, dropdownClassName), dropClass: classNames(styles.menu, menuClassName), open: open, onClick: handlePlaceholderClicked, onClickOutside: () => setOpen(false), onChange: (_e, _open) => _open && setKey((x) => x + 1), PlaceholderComponent: (_a) => {
                var { children } = _a, other = __rest(_a, ["children"]);
                return (React.createElement("div", Object.assign({}, other, { className: placeholderClassName, onClick: handlePlaceholderClicked }), children));
            }, placeholder: PlaceholderComponent },
            React.createElement(VersionMenu, { className: menuClassName, key: key, currentVersion: currentVersion, latestVersion: latestVersion, localVersion: localVersion, overrideVersionHref: overrideVersionHref, showVersionDetails: showVersionDetails, currentLane: currentLane, getActiveTabIndex: getActiveTabIndex, lanes: lanes, useVersions: useComponentVersions, open: open }))));
}
const defaultActiveTabIndex = (currentVersion, tabs = [], tags, snaps) => {
    if ((snaps || []).some((snap) => snap.version === currentVersion))
        return tabs.findIndex((tab) => tab.name === 'SNAP');
    return 0;
};
const VERSION_TAB_NAMES = ['TAG', 'SNAP', 'LANE'];
function _VersionMenu(_a) {
    var _b, _c;
    var { currentVersion, localVersion, latestVersion, overrideVersionHref, showVersionDetails, useVersions, currentLane, lanes, getActiveTabIndex = defaultActiveTabIndex, loading: loadingFromProps, open } = _a, rest = __rest(_a, ["currentVersion", "localVersion", "latestVersion", "overrideVersionHref", "showVersionDetails", "useVersions", "currentLane", "lanes", "getActiveTabIndex", "loading", "open"]);
    const { snaps, tags, loading: loadingVersions } = (useVersions === null || useVersions === void 0 ? void 0 : useVersions()) || {};
    const loading = loadingFromProps || loadingVersions;
    const tabs = React.useMemo(() => VERSION_TAB_NAMES.map((name) => {
        switch (name) {
            case 'SNAP':
                return { name, payload: snaps || [] };
            case 'LANE':
                return { name, payload: lanes || [] };
            default:
                return { name, payload: tags || [] };
        }
    }).filter((tab) => tab.payload.length > 0), [snaps === null || snaps === void 0 ? void 0 : snaps.length, tags === null || tags === void 0 ? void 0 : tags.length, lanes === null || lanes === void 0 ? void 0 : lanes.length, loading]);
    const [activeTabIndex, setActiveTab] = React.useState(getActiveTabIndex(currentVersion, tabs, tags, snaps, currentLane));
    const activeTab = React.useMemo(() => (activeTabIndex !== undefined ? tabs[activeTabIndex] : undefined), [activeTabIndex, tabs]);
    React.useEffect(() => {
        if (!currentLane)
            return;
        if (tabs.length === 0)
            return;
        const _activeTabIndex = getActiveTabIndex(currentVersion, tabs, tags, snaps, currentLane);
        if (_activeTabIndex !== activeTabIndex)
            setActiveTab(_activeTabIndex);
    }, [currentLane, tabs.length, tags === null || tags === void 0 ? void 0 : tags.length, snaps === null || snaps === void 0 ? void 0 : snaps.length, currentVersion, loading]);
    const multipleTabs = tabs.length > 1;
    const message = multipleTabs
        ? 'Switch to view tags, snaps, or lanes'
        : `Switch between ${(_b = tabs[0]) === null || _b === void 0 ? void 0 : _b.name.toLocaleLowerCase()}s`;
    const showTab = activeTabIndex !== undefined && ((_c = tabs[activeTabIndex]) === null || _c === void 0 ? void 0 : _c.payload.length) > 0;
    const _rowRenderer = React.useCallback(function VersionRowRenderer({ index }) {
        const { name, payload = [] } = activeTab || {};
        const item = payload[index];
        if (!item)
            return null;
        if (name === 'LANE') {
            const lane = item;
            return React.createElement(LaneInfo, Object.assign({ key: lane.id.toString(), currentLane: currentLane }, lane));
        }
        const version = item;
        return (React.createElement(VersionInfo, Object.assign({ key: version.version, currentVersion: currentVersion, latestVersion: latestVersion, overrideVersionHref: overrideVersionHref, showDetails: showVersionDetails }, version)));
    }, [activeTab, currentVersion, latestVersion, showVersionDetails, currentLane === null || currentLane === void 0 ? void 0 : currentLane.id.toString(), showTab]);
    const rowRenderer = React.useMemo(() => (showTab && activeTab ? _rowRenderer : () => null), [showTab, activeTab, _rowRenderer]);
    const ActiveTab = React.useMemo(() => {
        return activeTab === null || activeTab === void 0 ? void 0 : activeTab.payload.map((payload, index) => {
            return rowRenderer({ index });
        });
    }, [activeTab]);
    return (React.createElement("div", Object.assign({}, rest, { className: classNames(styles.versionMenuContainer, !open && styles.hide) }),
        React.createElement("div", { className: styles.top },
            loading && React.createElement(LineSkeleton, { count: 6, className: styles.loader }),
            !loading && React.createElement("div", { className: classNames(styles.titleContainer, styles.title) }, message),
            !loading && localVersion && (React.createElement(MenuLinkItem, { href: '?', active: currentVersion === LOCAL_VERSION, className: classNames(styles.versionRow, styles.localVersion) },
                React.createElement("div", { className: styles.version },
                    React.createElement(UserAvatar, { size: 24, account: {}, className: styles.versionUserAvatar }),
                    React.createElement("span", { className: styles.versionName }, LOCAL_VERSION))))),
        React.createElement("div", { className: classNames(multipleTabs && styles.tabs) }, multipleTabs &&
            tabs.map(({ name }, index) => {
                return (React.createElement(Tab, { className: styles.tab, key: name, isActive: activeTabIndex === index, onClick: () => setActiveTab(index) }, name));
            })),
        React.createElement("div", { className: styles.versionContainerRoot }, ActiveTab)));
}
//# sourceMappingURL=version-dropdown.js.map