import { MenuLinkItem } from '@teambit/design.ui.surfaces.menu.link-item';
import { TimeAgo } from '@teambit/design.ui.time-ago';
import { VersionLabel } from '@teambit/component.ui.version-label';
import React, { useMemo, useRef, useEffect } from 'react';
import { UserAvatar } from '@teambit/design.ui.avatar';
import { Ellipsis } from '@teambit/design.ui.styles.ellipsis';
import classNames from 'classnames';
import styles from './version-info.module.scss';
export const VersionInfo = React.memo(React.forwardRef(_VersionInfo));
function _VersionInfo({ version, currentVersion, latestVersion, date, username, displayName, email, overrideVersionHref, showDetails, message, tag, profileImage, }, ref) {
    const isCurrent = version === currentVersion;
    const author = useMemo(() => {
        return {
            displayName: displayName !== null && displayName !== void 0 ? displayName : '',
            email,
            name: username !== null && username !== void 0 ? username : '',
            profileImage,
        };
    }, [displayName, email, username, profileImage]);
    const timestamp = useMemo(() => (date ? new Date(parseInt(date)).toString() : new Date().toString()), [date]);
    const currentVersionRef = useRef(null);
    useEffect(() => {
        var _a;
        if (isCurrent) {
            (_a = currentVersionRef.current) === null || _a === void 0 ? void 0 : _a.scrollIntoView({ block: 'nearest' });
        }
    }, [isCurrent]);
    const href = overrideVersionHref ? overrideVersionHref(version) : `?version=${version}`;
    const formattedVersion = useMemo(() => {
        return tag ? version : version.slice(0, 6);
    }, [tag, version]);
    const isLatest = version === latestVersion;
    return (React.createElement("div", { ref: ref || currentVersionRef },
        React.createElement(MenuLinkItem, { active: isCurrent, href: href, className: styles.versionRow },
            React.createElement("div", { className: styles.version },
                React.createElement(UserAvatar, { size: 24, account: author, className: styles.versionUserAvatar, showTooltip: true }),
                React.createElement(Ellipsis, { className: classNames(styles.versionName) }, formattedVersion),
                isLatest && React.createElement(VersionLabel, { status: "latest" }),
                React.createElement(CommitMessage, { message: message, showDetails: showDetails })),
            React.createElement(Ellipsis, { className: styles.versionTimestamp },
                React.createElement(TimeAgo, { date: timestamp })))));
}
function CommitMessage({ message, showDetails }) {
    if (!showDetails)
        return null;
    if (!message || message === '')
        return React.createElement(Ellipsis, { className: styles.emptyMessage }, "No commit message");
    return React.createElement(Ellipsis, { className: styles.commitMessage }, message);
}
//# sourceMappingURL=version-info.js.map